#!/usr/bin/env python
# -*- coding: utf-8 -*-
"""
$Id: DS18B20autolocation.py,v 1.2 2014/05/31 11:52:30 alfille Exp $

Copyright (c) 2014 C-Bell (VAGor). All rights reserved.

Модуль автоматически определяет и сохраняет в базе данных
места расположения цифровых термометров DS18B20

Нужно аппаратуру заправить водой и запустить данный модуль.
По завершении его работы в БД будут сохранены места расположения
цифровых термометров DS18B20 (в таблице DS18B20cur).

"""

import DS18B20db
import actuators, sqlite3, time, Power
from actuators import *

#Отключение всех реле
OffAll()

#Запуск процесса сбора температурных данных
DS18B20db.StartMeasure()

#Установка полной мощности
Power.Set(10)

#Запуск преобразования Брезенхема
Power.On()
print("Включение 100% нагрева")

#Места расположения термометров:
locations=[u"Куб",u"1/2",u"Верх",u"Деф",u"Конд"]

#Cоединение с базой данных
db_con=sqlite3.connect("Distiller.db")
#Создание курсора БД
db_cur=db_con.cursor()

#Нужно подождать пару секунд, ибо измерение температуры не быстро делается
time.sleep(2)

#Хранилище максимальной температуры
Tmax=0

#Ждем нагрева до 75
while True:
    #Читаем максимальную температуру из БД
    db_cur.execute("SELECT MAX(T) FROM DS18B20cur")
    Tmax,=db_cur.fetchone()
    if Tmax>75:
        #Уменьшаем мощность до 30%
        Power.Set(3)
        print("Мощность снижена до 30%")
        #Включаем клапаны
        OnDeph()
        OnCond()
        print("Клапаны дефлегматора и конденсатора включены")
        break
    time.sleep(1.2)
print("Стабилизация 70 сек")
#Стабилизация 20 сек
time.sleep(20)
Power.Set(5)
print("Мощность увеличена до 50%")
time.sleep(50)

#Счетчик проверок стабильности температуры
count=10
print("Цикл ожидания стабилизации")
#Ждем стабилизации температуры
while count:
    db_cur.execute("SELECT MAX(T) FROM DS18B20cur")
    T,=db_cur.fetchone()
    if T-Tmax<0.25:
        count-=1
    else:
        count=10
        Tmax=T
    time.sleep(1.2)

#Запрашиваем из БД ID термометров в порядке убывания температур
db_cur.execute("SELECT ID FROM DS18B20cur ORDER BY T DESC")

#Запоминаем порядок
#order=db_cur.fetchall()
i=0

#Присваиваем названия в порядке убывания температур
for dt in db_cur.fetchall():
    ID,=dt
    db_cur.execute("UPDATE DS18B20cur SET Name=? WHERE ID=?", (locations[i],ID))
    i+=1
#Сохраняем БД
db_con.commit()
#Отключаем нарев
Power.Off()
#Отключаем всё
OffAll()

print ("Автоопределение мест подключения термометров завершено, данные сохранены в БД.")
db_cur.execute("SELECT * FROM DS18B20cur ORDER BY T DESC")
for dt in db_cur:
    print(u"%s %s %s"%dt)
##time.sleep(2)
##db_cur.execute("SELECT * FROM DS18B20cur WHERE Name='Куб'")
##T1=db_cur.fetchone()
##db_cur.execute("SELECT * FROM DS18B20cur WHERE Name='1/2'")
##T2=db_cur.fetchone()
##db_cur.execute("SELECT * FROM DS18B20cur WHERE Name='Верх'")
##T3=db_cur.fetchone()
##db_cur.execute("SELECT * FROM DS18B20cur WHERE Name='Деф'")
##T4=db_cur.fetchone()
##db_cur.execute("SELECT * FROM DS18B20cur WHERE Name='Конд'")
##T5=db_cur.fetchone()
##print("%s %s %s, %s %s %s, %s %s %s, %s %s %s, %s %s %s" % (T1[0],T1[1],T1[2],T2[0],T2[1],T2[2],T3[0],T3[1],T3[2],T4[0],T4[1],T4[2],T5[0],T5[1],T5[2]))

#Останавливаем запись температур в БД
DS18B20db.StopMeasure()

#print db_cur.fetchall()
#Закрываем соединение с БД
#db_con.close()

