#!/usr/bin/env python
#coding=utf8
"""
$Id: Power.py,v 1.2 2014/05/29 11:52:30 alfille Exp $

Copyright (c) 2014 C-Bell (VAGor). All rights reserved.

Модуль обеспечивает регулировку уровня выдаваемый на ТЭНы
мощности по алгоритму Брезенхема.

Для работы программы должны быть установлены пакеты:
    gpio
"""

import actuators, threading, time
from actuators import *

Pmax=5
P=0
#Разрешитель работы потока преобразования Брезенхема
Convert=False

def On():
    """Стартует поток регулятора мощности"""
    global Convert
    Convert=True
    thrdPwr=threading.Thread(target=Power)
    print("Старт потока регулятора мощности")
    thrdPwr.start()

def Off():
    """Останавливает поток регулятора"""
    print("Останов потока регулятора мощности")
    global Convert
    Convert=False

def Set(Pwr):
    """Установка мощности"""
    global P
    P=Pwr
    if P>10:
        P=10
    if P<0:
        P=0

def Power():
    """Реализация алгоритма Брезенхема для распределения мощности
    на два ТЭНа"""
    while Convert:
        #print("P=%s",P)
        P1=P/2
        P2=P-P1
        ErrP1=Pmax-P1
        ErrP2=Pmax-(Pmax-P2)
        for x in range(Pmax):
            if ErrP1<Pmax/2:
                ErrP1+=Pmax
                OnTEH1()
            else:
                OffTEH1()
            ErrP1-=P1
            if ErrP2<Pmax/2:
                ErrP2+=Pmax
                OffTEH2()
            else:
                OnTEH2()
            ErrP2-=Pmax-P2
            time.sleep(1)
        OffTEH1()
        OffTEH2()

def main():
    """Ручная установка мощности и тестовое преобразование"""
    On()
    while True:
        End=raw_input("Значение мощности (0...10) или Enter для останова:")
        if End=="":
            Off()
            break
        try:
            Set(int(End))
        except ValueError:
            pass

if __name__=="__main__":
    try:
        main()
    finally:
        Off()
